# Python imports
import json
import os

# Configuration
projects_dir = '/home/jovyan/write/projects/all-hands'
# Sort the list of projects
projects = sorted(os.listdir(projects_dir))

def get_all(projects):
    # Get a list of all project config files
    config_paths = [os.path.join(projects_dir, project + '/config/config.json') for project in projects if not project.startswith('.ipynb')]
    rows = []
    # Open each project config and get the metadata (if present) for each visualisation
    for project in config_paths:
      with open(project, 'r') as f:
        doc = json.loads(f.read())
      for viz in doc['visualizations']:
        if 'name' in viz:
            name = viz['name']
        else:
            name = 'None'
        if 'path' in viz:
            path = viz['path']
        else:
            path = 'None'
        # Save the row as a list
        rows.append(list(name, path, doc['metadata']['project_name']))
    return rows

def save_html_file(projects):
    html = """
    <html>
    <head>
    <meta charset="utf-8">
    <title>Table of All Projects</title>
    <!-- CSS -->
    <link rel="stylesheet" type="text/css" href="https://cdn.datatables.net/v/bs4/jszip-2.5.0/dt-1.10.18/b-1.5.6/b-html5-1.5.6/fc-3.2.5/fh-3.1.4/r-2.2.2/sc-2.0.0/datatables.min.css"/>
    <!-- scripts -->
    <script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.36/pdfmake.min.js"></script>
    <script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.36/vfs_fonts.js"></script>
    <script type="text/javascript" src="https://cdn.datatables.net/v/bs4/jszip-2.5.0/dt-1.10.18/b-1.5.6/b-html5-1.5.6/fc-3.2.5/fh-3.1.4/r-2.2.2/sc-2.0.0/datatables.min.js"></script>
    $(document).ready(function () {
        var data = []
        $('#projects').DataTable( {
            'data': data
        })
    })
    </head>
    <body>
    <table id="projects" class="display">
        <thead>
            <tr>
                <th>Name</th>
                <th>Path</th>
                <th>Project</th>
            </tr>
        </thead>
    </table>
    </body>
    </html>
    """
    rows = get_all(projects)
    html.replace('var data = []', 'var data = ' + rows)
    with open('/home/jovyan/view/projects/scripts/all-projects.html', 'w') as f:
        f.write(html)